pub struct Resources { /* private fields */ }Expand description
Container for engine resources.
Resources are stored by type and can be accessed through typed getters. Each resource type can only have one instance.
Example
use astrelis::resource::Resources;
struct GameConfig {
title: String,
max_fps: u32,
}
let mut resources = Resources::new();
resources.insert(GameConfig {
title: "My Game".to_string(),
max_fps: 60,
});
let config = resources.get::<GameConfig>().unwrap();
assert_eq!(config.title, "My Game");Implementations
Sourceimpl Resources
impl Resources
Sourcepub fn insert<R: Resource>(&mut self, resource: R) -> Option<R>
pub fn insert<R: Resource>(&mut self, resource: R) -> Option<R>
Insert a resource, replacing any existing resource of the same type.
Returns the previous resource if one existed.
Sourcepub fn get_mut<R: Resource>(&mut self) -> Option<&mut R>
pub fn get_mut<R: Resource>(&mut self) -> Option<&mut R>
Get a mutable reference to a resource.
Sourcepub fn get_or_insert_with<R: Resource>(
&mut self,
f: impl FnOnce() -> R,
) -> &mut R
pub fn get_or_insert_with<R: Resource>( &mut self, f: impl FnOnce() -> R, ) -> &mut R
Get or insert a resource with a default value.
Sourcepub fn get_or_default<R: Resource + Default>(&mut self) -> &mut R
pub fn get_or_default<R: Resource + Default>(&mut self) -> &mut R
Get or insert a resource with its default value.
Sourcepub fn type_names(&self) -> impl Iterator<Item = &'static str> + '_
pub fn type_names(&self) -> impl Iterator<Item = &'static str> + '_
List all resource type names (for debugging).